summaryrefslogtreecommitdiffstats
path: root/src/DotNetOpenAuth.OAuth2/OAuth2
diff options
context:
space:
mode:
authorAndrew Arnott <andrewarnott@gmail.com>2012-02-12 18:37:40 -0800
committerAndrew Arnott <andrewarnott@gmail.com>2012-02-12 18:37:40 -0800
commitfb504a4573992f0ef7742f5c34e4e85a945b710c (patch)
treefb769c13b917a3d0bd32db0c22e79bb8d5d459c6 /src/DotNetOpenAuth.OAuth2/OAuth2
parent7bf63044b1a48dc6f1df95c63431e8130940595d (diff)
downloadDotNetOpenAuth-fb504a4573992f0ef7742f5c34e4e85a945b710c.zip
DotNetOpenAuth-fb504a4573992f0ef7742f5c34e4e85a945b710c.tar.gz
DotNetOpenAuth-fb504a4573992f0ef7742f5c34e4e85a945b710c.tar.bz2
Renamed IConsumerDescription to IClientDescription.
Diffstat (limited to 'src/DotNetOpenAuth.OAuth2/OAuth2')
-rw-r--r--src/DotNetOpenAuth.OAuth2/OAuth2/IAuthorizationServer.cs6
-rw-r--r--src/DotNetOpenAuth.OAuth2/OAuth2/IClientDescription.cs (renamed from src/DotNetOpenAuth.OAuth2/OAuth2/IConsumerDescription.cs)20
-rw-r--r--src/DotNetOpenAuth.OAuth2/OAuth2/OAuthUtilities.cs4
3 files changed, 15 insertions, 15 deletions
diff --git a/src/DotNetOpenAuth.OAuth2/OAuth2/IAuthorizationServer.cs b/src/DotNetOpenAuth.OAuth2/OAuth2/IAuthorizationServer.cs
index 23c4a75..9c2888f 100644
--- a/src/DotNetOpenAuth.OAuth2/OAuth2/IAuthorizationServer.cs
+++ b/src/DotNetOpenAuth.OAuth2/OAuth2/IAuthorizationServer.cs
@@ -88,7 +88,7 @@ namespace DotNetOpenAuth.OAuth2 {
/// <param name="clientIdentifier">The client identifier.</param>
/// <returns>The client registration. Never null.</returns>
/// <exception cref="ArgumentException">Thrown when no client with the given identifier is registered with this authorization server.</exception>
- IConsumerDescription GetClient(string clientIdentifier);
+ IClientDescription GetClient(string clientIdentifier);
/// <summary>
/// Determines whether a described authorization is (still) valid.
@@ -202,9 +202,9 @@ namespace DotNetOpenAuth.OAuth2 {
/// <param name="clientIdentifier">The client identifier.</param>
/// <returns>The client registration. Never null.</returns>
/// <exception cref="ArgumentException">Thrown when no client with the given identifier is registered with this authorization server.</exception>
- IConsumerDescription IAuthorizationServer.GetClient(string clientIdentifier) {
+ IClientDescription IAuthorizationServer.GetClient(string clientIdentifier) {
Requires.NotNullOrEmpty(clientIdentifier, "clientIdentifier");
- Contract.Ensures(Contract.Result<IConsumerDescription>() != null);
+ Contract.Ensures(Contract.Result<IClientDescription>() != null);
throw new NotImplementedException();
}
diff --git a/src/DotNetOpenAuth.OAuth2/OAuth2/OAuthUtilities.cs b/src/DotNetOpenAuth.OAuth2/OAuth2/OAuthUtilities.cs
index f3bceda..a032ed5 100644
--- a/src/DotNetOpenAuth.OAuth2/OAuth2/OAuthUtilities.cs
+++ b/src/DotNetOpenAuth.OAuth2/OAuth2/OAuthUtilities.cs
@@ -107,9 +107,9 @@ namespace DotNetOpenAuth.OAuth2 {
/// <param name="authorizationServer">The authorization server.</param>
/// <param name="clientIdentifier">The client identifier.</param>
/// <returns>The client information. Never null.</returns>
- internal static IConsumerDescription GetClientOrThrow(this IAuthorizationServer authorizationServer, string clientIdentifier) {
+ internal static IClientDescription GetClientOrThrow(this IAuthorizationServer authorizationServer, string clientIdentifier) {
Requires.NotNullOrEmpty(clientIdentifier, "clientIdentifier");
- Contract.Ensures(Contract.Result<IConsumerDescription>() != null);
+ Contract.Ensures(Contract.Result<IClientDescription>() != null);
try {
return authorizationServer.GetClient(clientIdentifier);
diff --git a/src/DotNetOpenAuth.OAuth2/OAuth2/IConsumerDescription.cs b/src/DotNetOpenAuth.OAuth2/OAuth2/IClientDescription.cs
index 47073e8..84eb6b6 100644
--- a/src/DotNetOpenAuth.OAuth2/OAuth2/IConsumerDescription.cs
+++ b/src/DotNetOpenAuth.OAuth2/OAuth2/IClientDescription.cs
@@ -1,5 +1,5 @@
//-----------------------------------------------------------------------
-// <copyright file="IConsumerDescription.cs" company="Outercurve Foundation">
+// <copyright file="IClientDescription.cs" company="Outercurve Foundation">
// Copyright (c) Outercurve Foundation. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
@@ -12,8 +12,8 @@ namespace DotNetOpenAuth.OAuth2 {
/// <summary>
/// A description of a client from an Authorization Server's point of view.
/// </summary>
- [ContractClass(typeof(IConsumerDescriptionContract))]
- public interface IConsumerDescription {
+ [ContractClass(typeof(IClientDescriptionContract))]
+ public interface IClientDescription {
/// <summary>
/// Gets the client secret.
/// </summary>
@@ -54,17 +54,17 @@ namespace DotNetOpenAuth.OAuth2 {
}
/// <summary>
/// Contract class for the <see cref="IConsumerDescription"/> interface.
/// </summary>
- [ContractClassFor(typeof(IConsumerDescription))]
- internal abstract class IConsumerDescriptionContract : IConsumerDescription {
- #region IConsumerDescription Members
+ [ContractClassFor(typeof(IClientDescription))]
+ internal abstract class IClientDescriptionContract : IClientDescription {
+ #region IClientDescription Members
/// <summary>
/// Gets the client secret.
/// </summary>
/// <value></value>
- string IConsumerDescription.Secret {
+ string IClientDescription.Secret {
get { throw new NotImplementedException(); }
}
@@ -75,7 +75,7 @@ namespace DotNetOpenAuth.OAuth2 {
/// <value>
/// An absolute URL; or <c>null</c> if none is registered.
/// </value>
- Uri IConsumerDescription.DefaultCallback {
+ Uri IClientDescription.DefaultCallback {
get {
Contract.Ensures(Contract.Result<Uri>() == null || Contract.Result<Uri>().IsAbsoluteUri);
throw new NotImplementedException();
@@ -90,7 +90,7 @@ namespace DotNetOpenAuth.OAuth2 {
/// <returns>
/// <c>true</c> if the callback is allowed; otherwise, <c>false</c>.
/// </returns>
- bool IConsumerDescription.IsCallbackAllowed(Uri callback) {
+ bool IClientDescription.IsCallbackAllowed(Uri callback) {
Requires.NotNull(callback, "callback");
Requires.True(callback.IsAbsoluteUri, "callback");
throw new NotImplementedException();
@@ -54,17 +54,17 @@ namespace DotNetOpenAuth.OAuth2 {
}
/// <summary>
- /// Contract class for the <see cref="IConsumerDescription"/> interface.
+ /// Contract class for the <see cref="IClientDescription"/> interface.
/// </summary>